@@ -12,7 +12,15 @@ template = env.get_template("image_template.html")
 
 
 def image_template(
-    url, alt, hi_def, width, height=None, fill=False, loading="lazy", attrs={},
+    url,
+    alt,
+    hi_def,
+    width,
+    height=None,
+    fill=False,
+    e_sharpen=False,
+    loading="lazy",
+    attrs={},
 ):
     """
     Generate image markup
@@ -29,6 +37,9 @@ def image_template(
         "fl_sanitize",  # Sanitize SVG content
     ]
 
+    if e_sharpen:
+        cloudinary_options.append("e_sharpen")
+
     # If the original image does not match the requested
     # ratio set crop and fill see
     # https://cloudinary.com/documentation/image_transformation_reference#crop_parameter
